@@ -22,7 +22,7 @@
 # logger for each part
 # cookiejar
 
-__version__="0.5.5" #autoreload's version !
+__version__="0.5.7" #autoreload's version !
 
 import os,sys,re,traceback,copy,types
 from urllib.parse import urlparse
@@ -302,8 +302,9 @@ class WebSocketHandler(tornado.websocket.WebSocketHandler):
         del WebSocketHandler.clients[self]
 
     async def on_message(self, message):
-
-        instance = WebSocketHandler.clients[self]
+        instance = WebSocketHandler.clients.get(self,None)
+        if instance is None:
+            return
 
         o = jLoads(message)
         logger.debug("WS RECEPT: %s",o)
